﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Telerik.WinControls;
using Telerik.WinControls.Layout;
using Telerik.WinControls.UI;

namespace TagCloud
{
    public class TagCloudElement : RadElement
    {
        List<TagCloudDataItem> items;
        WrapLayoutPanel panel;
        public double MinFontHeight { get; set; }
        public double MaxFontHeight { get; set; }

        public TagCloudElement()
        {
            items = new List<TagCloudDataItem>();
        }

        protected override void CreateChildElements()
        {
            base.CreateChildElements();

            panel = new WrapLayoutPanel();
            this.Children.Add(panel);
        }

        public List<TagCloudDataItem> Items
        {
            get
            {
                return this.items;
            }
            set
            {
                this.items = value;

                double maxWeight = items[items.Count - 1].Weight;
                double minWeight = items[0].Weight;

                foreach (TagCloudDataItem item in this.items)
                {
                    if (item.Weight < minWeight) minWeight = item.Weight;
                    if (item.Weight > maxWeight) maxWeight = item.Weight;
                }

                double factor = (MaxFontHeight - MinFontHeight) / (maxWeight - minWeight);

                foreach (TagCloudDataItem item in this.items)
                {
                    RadLabelElement label = new RadLabelElement();
                    label.Text = item.Text;
                    label.Click += delegate { Process.Start(item.NavigateUrl); };
                    label.MouseEnter += delegate { label.ForeColor = Color.Blue; };
                    label.MouseLeave += delegate { label.ForeColor = Color.Black; };

                    float fontSize = (float)(((item.Weight - minWeight) * factor) + MinFontHeight);
                    label.Font = new Font("Segoe UI", fontSize);

                    panel.Children.Add(label);
                }
            }
        }
    }
}
